@@ -16,10 +16,11 @@ use Carp;
 use strict;
 use base qw(Exporter);
 use vars qw($VERSION @EXPORT @ISA $AUTOLOAD $_HAVE_NOT_URI_FIND);
-$VERSION 	= "0.08";
+$VERSION 	= "0.09";
 @EXPORT  	= qw();
 @ISA	 	= qw(Mail::MboxParser::Base Mail::MboxParser::Mail);
 
+use overload '""' => \&as_string, fallback => 1;
 
 BEGIN { 
 	eval { require URI::Find; };
@@ -34,7 +35,7 @@ sub init(@) {
 	$self;
 }
 
-sub as_string() {	
+sub as_string {	
 	my ($self, %args) = @_;
     $self->reset_last;
     return join "", $self->as_lines(strip_sig => 1) if $args{strip_sig};
@@ -286,7 +287,7 @@ Unfortunately, quotes() can up to now only deal with '>' as quotation-marks.
 
 =head1 VERSION
 
-This is version 0.34.
+This is version 0.36.
 
 =head1 AUTHOR AND COPYRIGHT
 
